import json
import urllib.error
import urllib.request
from html.parser import HTMLParser
from io import StringIO


class MLStripper(HTMLParser):
    def __init__(self):
        super().__init__()
        self.reset()
        self.strict = False
        self.convert_charrefs = True
        self.text = StringIO()

    def handle_data(self, d):
        self.text.write(d)

    def get_data(self):
        return self.text.getvalue()


def strip_tags(html):
    s = MLStripper()
    s.feed(html)
    return s.get_data()


class Definition:
    def __init__(self):
        self.parsedExamples = {}
        self.examples = []
        self.definition = ""


class WiktionaryResult:
    def __init__(self):
        self.partOfSpeech = ""
        self.definitions = []
        self.definitionList = []
        self.rawResult = dict()

    def query(self, word: str, lang: str):
        api = 'https://en.wiktionary.org/api/rest_v1/page/definition/'
        try:
            with urllib.request.urlopen(api + word) as url:
                data = json.loads(url.read().decode())
                self.rawResult = data
                if "partOfSpeech" in data[lang][0]:
                    self.partOfSpeech = data[lang][0]["partOfSpeech"]
                for definition in data[lang][0]["definitions"]:
                    defi = Definition()
                    content = strip_tags(definition["definition"])
                    defi.definition = content

                    if "parsedExamples" in definition:
                        parsed_examples = definition["parsedExamples"]
                        for entry in parsed_examples:
                            defi.parsedExamples[strip_tags(entry["example"])] = strip_tags(entry["translation"])

                    if "examples" in definition:
                        for example in definition["examples"]:
                            defi.examples.append(strip_tags(example))

                    self.definitions.append(content)
                    self.definitionList.append(defi)
                    return True
        except KeyError:
            print("Word not found in Language")
            return False
        except urllib.error.HTTPError:
            print("No internet or word not found")
            return False






import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
  name = 'wiktionary_translate',         # How you named your package folder (MyLib)
  packages = ['wiktionary_translate'],   # Chose the same as "name"
  version = '0.0.5',      # Start with a small number and increase it with every change you make
  license='mpl-2.0',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Get English translations of foreign word with Wiktionary',   # Give a short description about your library
  author = 'Marvin perzi',                   # Type in your name
  author_email = 'hashcod3@protonmail.com',      # Type in your E-Mail
  long_description = long_description,
  long_description_content_type = 'text/markdown',
  url = 'https://github.com/Persie0/wiktionary_translate',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/Persie0/wiktionary_translate/archive/refs/tags/v0.0.5.tar.gz',    # I explain this later on
  keywords = ['wiktionary', 'dictionary'],   # Keywords that define your package best
  classifiers=[
    'Development Status :: 5 - Production/Stable',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: Mozilla Public License 2.0 (MPL 2.0)',   # Again, pick a license
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3.9',
    'Programming Language :: Python :: 3.10',
  ],
)